@@ -192,11 +192,13 @@ def format_exc_info(etype, evalue, tb, style='plaintext', add_summary='auto',
                                             exc,
                                             exc.__traceback__,
                                             chain=False)
-
-        msg = 'Stackprinter failed:\n%s' % ''.join(our_tb[-2:])
-        msg += 'So here is the original traceback at least:\n\n'
+        where = getattr(exc, 'where', None)
+        context = " while formatting " + str(where) if where else ''
+        msg = 'Stackprinter failed%s:\n%s\n' % (context, ''.join(our_tb[-2:]))
+        msg += 'So here is your original traceback at least:\n\n'
         msg += ''.join(traceback.format_exception(etype, evalue, tb))
 
+
     return msg
 
 
