@@ -12,7 +12,7 @@ from stackprinter.utils import inspect_callable, match, trim_source, get_ansi_tp
 class FrameFormatter():
     headline_tpl = "File %s, line %s, in %s\n"
     sourceline_tpl = "    %-3s  %s"
-    single_sourceline_tpl = "   %s"
+    single_sourceline_tpl = "    %s"
     marked_sourceline_tpl = "--> %-3s  %s"
     elipsis_tpl = " (...)\n"
     var_indent = 5
@@ -98,7 +98,7 @@ class FrameFormatter():
             The only difference between passing a frame or a traceback object is
             which line gets highlighted in the source listing: For a frame, it's
             the currently executed line; for a traceback, it's the line where an
-            error occured. (technically: `frame.f_lineno` vs. `tb.tb_lineno`)
+            error occurred. (technically: `frame.f_lineno` vs. `tb.tb_lineno`)
 
             The third option is interesting only if you're planning to format
             one frame multiple different ways: It is a little faster to format a
@@ -116,15 +116,22 @@ class FrameFormatter():
             raise ValueError("Expected one of these types: "
                              "%s. Got %r" % (accepted_types, frame))
 
-        if isinstance(frame, ex.FrameInfo):
-            finfo = frame
-        else:
-            finfo = ex.get_info(frame, lineno)
+        try:
+            if isinstance(frame, ex.FrameInfo):
+                finfo = frame
+            else:
+                finfo = ex.get_info(frame, lineno)
+
+            return self._format_frame(finfo, self.lines, self.lines_after, self.show_vals,
+                                      self.show_signature, self.truncate_vals,
+                                      self.suppressed_paths)
+        except Exception as exc:
+            if isinstance(frame, ex.FrameInfo):
+                exc.where = [finfo.filename, finfo.function, finfo.lineno]
+            else:
+                exc.where = frame
+            raise
 
-        msg = self._format_frame(finfo, self.lines, self.lines_after, self.show_vals,
-                                 self.show_signature, self.truncate_vals,
-                                 self.suppressed_paths)
-        return msg
 
     def _format_frame(self, fi, lines, lines_after, show_vals,
                       show_signature, truncate_vals, suppressed_paths):
@@ -215,6 +222,12 @@ def select_scope(fi, lines, lines_after, show_vals, show_signature,
             source_lines = sorted(set(source_lines) | set(fi.head_lns))
 
     if source_lines:
+        # Report a bit more info about a weird class of bug
+        # that I can't reproduce locally.
+        if not set(source_lines).issubset(fi.source_map.keys()):
+            debug_vals = [source_lines, fi.head_lns, fi.source_map.keys()]
+            info = ', '.join(str(p) for p in debug_vals)
+            raise Exception("Picked an invalid source context: %s" % info)
         trimmed_source_map = trim_source(fi.source_map, source_lines)
     else:
         trimmed_source_map = {}
